<?php
/*
 * StudipAuthAlija.class.php - Stud.IP authentication against external server
 * Copyright (c) 2007  Elmar Ludwig
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 */

require_once 'StudipAuthAbstract.class.php';

if (version_compare(PHP_VERSION, '5.2', '<')) {
    // emulate the built-in JSON extension of PHP 5.2
    require_once 'vendor/phpxmlrpc/xmlrpc.inc';
    require_once 'vendor/phpxmlrpc/jsonrpc.inc';
    require_once 'vendor/phpxmlrpc/json_extension_api.inc';
}

class StudipAuthAlija extends StudipAuthAbstract
{
    var $trusted_hosts;
    var $userdata;

    /**
     * Constructor: check validate parameter and fetch auth data.
     */
    function StudipAuthAlija ()
    {
        parent::StudipAuthAbstract();

        $this->userdata = array();

        if (is_array($this->trusted_hosts)) {
            foreach ($this->trusted_hosts as $host) {
                $url = $host['url'];
                if (strncasecmp($_REQUEST['validate'], $url, strlen($url)) == 0) {
                    $validate_url = $_REQUEST['validate'];
                    $user_domain  = $host['domain'];
                    break;
                }
            }
        }

        if (isset($validate_url)) {
            $result = file_get_contents($validate_url);
            $this->userdata = json_decode($result, true);
            $this->userdata = array_map('utf8_decode', $this->userdata);

            $parts = explode('@', $this->userdata['username']);

            if (!empty($parts[1])) {
                $this->userdata['username'] = $parts[0];
                $this->userdata['domain']   = $parts[1];
            } else if (isset($user_domain)) {
                $this->userdata['domain'] = $user_domain;
            }
        }
    }

    /**
     * Return the current username (including domain part).
     */
    function getUser ()
    {
        $username = $this->userdata['username'];
        $domain   = $this->userdata['domain'];

        if ($username != '' && $domain != '') {
            return $username.'@'.$domain;
        } else {
            return $username;
        }
    }

    /**
     * Validate the username passed to the auth plugin.
     */
    function verifyUsername ($username)
    {
        return $this->getUser();
    }

    /**
     * Check whether this user can be authenticated.
     */
    function isAuthenticated ($username, $password, $jscript)
    {
        return !empty($username);
    }

    /**
     * This auth plugin cannot determine if a username is used.
     */
    function isUsedUsername ($username)
    {
        return false;
    }

    /**
     * Callback that can be used in user_data_mapping array.
     */
    function getUserData ($key)
    {
        return $this->userdata[$key];
    }
}
?>
